bbprep.selectors.Selector
=========================

.. currentmodule:: bbprep.selectors

.. autoclass:: Selector
   :members:
   :inherited-members:
   :undoc-members:
   :show-inheritance:


   
   
   .. rubric:: Methods

   .. autosummary::
      :nosignatures:
   
      ~Selector.get_atomic_positions
      ~Selector.select_atoms
      ~Selector.yield_stepwise
   
   

   
   
   